@@ -25,7 +25,7 @@ a given header takes <10 lines of code::
             self._expected = expected
 
         def _match(self, request):
-            return self._expected in self.request.headers
+            return self._expected in request.headers
 
 An then you only need to import the new defined matcher and write
 your expectation::
@@ -145,12 +145,44 @@ class Matcher(object):
     def __name(self):
         return type(self).__name__.replace('_', ' ').strip()
 
+    def _match_value(self, matcher, value):
+        """This method receives a :class:`Matcher` instance and a
+        `value to be matched` as first and second arguments respectively,
+        and returns :keyword:`True` or :keyword:`False` depending on
+        whether the `value` matches.
+
+        If the argument passed as `matcher` does not implements the
+        :class:`Matcher` interface then the :keyword:`equal` built-in
+        matcher is used.
+
+        Examples::
+
+            >>> self._match_value('foo', 'foo')
+            True
+            >>> self._match_value('foo', 'bar')
+            False
+            >>> self._match_value(match('\w+'), 'foo')
+            True
+
+        :param matcher: A matcher that will be used to match the given value.
+        :param value: A value to test if matches.
+        :rtype: bool
+
+        """
+
+        if not hasattr(matcher, '_match'):
+            matcher = equal_matcher(matcher)
+
+        return matcher._match(value)
+
     def __and__(self, other):
         return _And(self, other)
 
     def __or__(self, other):
         return _Or(self, other)
 
+from .built_in import equal as equal_matcher
+
 
 class _And(Matcher):
     def __init__(self, op1, op2):
